@@ -4,27 +4,31 @@ package Class::DBI::Lite::Iterator;
 use strict;
 use warnings 'all';
 
-#==============================================================================
+
 sub new
 {
   my ($class, $data) = @_;
   
-  return bless {
+  my $s = bless {
     data => $data,
     count => scalar(@$data),
     idx   => 0
   }, $class;
+  $s->init();
+  
+  return $s;
 }# end new()
 
 
-#==============================================================================
+sub init { }
+
+
 sub first
 {
   $_[0]->{data}->[0];
 }# end first()
 
 
-#==============================================================================
 sub next
 {
   my $s = shift;
@@ -33,14 +37,12 @@ sub next
 }# end next()
 
 
-#==============================================================================
 sub count
 {
   $_[0]->{count};
 }# end count()
 
 
-#==============================================================================
 sub reset
 {
   $_[0]->{idx} = 0;
@@ -48,7 +50,6 @@ sub reset
 
 1;# return true:
 
-__END__
 
 =pod
 
